@@ -32,12 +32,14 @@ setMethod(
   definition = function(objectName, sim, module) {
     i <- 0
     lenSC <- length(sys.calls())
+    # This will get the simList that is closest in the call stack, noting that
+    #  in this first one (i.e., this function), sim will be missing
     while (missing(sim) && i < lenSC) {
       i <- i + 1
       simEnv <- whereInStack("sim", -i)
       sim <- simEnv$sim
     }
-    extractURL(objectName = objectName, sim = sim)
+    extractURL(objectName = objectName, sim = sim, module = module)
 })
 
 #' @export
@@ -108,7 +110,7 @@ checksums <- function(module, path, ...) {
 
 #' Determine the size of a remotely hosted file
 #'
-#' Query a remote web server to determine the size of a remote file.
+#' Deprecated.
 #'
 #' @param url  The url of the remote file.
 #'
@@ -116,28 +118,24 @@ checksums <- function(module, path, ...) {
 #'
 #' @author Eliot McIntire and Alex Chubaty
 #' @export
-#' @importFrom RCurl url.exists
-#'
-#' @examples
-#' urls <- c("https://www.alexchubaty.com/uploads/2011/11/open-forest-science-journal.csl",
-#'           "https://www.alexchubaty.com/uploads/2011/08/models_GUI_2011-08-07.zip",
-#'           "http://example.com/doesntexist.csv")
-#' try(remoteFileSize(urls)) ## 5429, 3997384, 0
 #'
 remoteFileSize <- function(url) {
-  contentLength <- vapply(url, function(u) {
-    header <- RCurl::url.exists(u, .header = TRUE)
-    status <- tryCatch(as.numeric(header[["status"]]), error = function(e) 0)
-    if (status == 200) {
-      as.numeric(header[["Content-Length"]])
-    } else {
-      0
-    }
-  }, numeric(1))
-
-  return(contentLength)
+  .Deprecated()
+  # contentLength <- vapply(url, function(u) {
+  #   header <- RCurl::url.exists(u, .header = TRUE)
+  #   status <- tryCatch(as.numeric(header[["status"]]), error = function(e) 0)
+  #   if (status == 200) {
+  #     as.numeric(header[["Content-Length"]])
+  #   } else {
+  #     0
+  #   }
+  # }, numeric(1))
+  #
+  # return(contentLength)
 }
 
+
+
 ################################################################################
 #' Download module data
 #'
@@ -201,8 +199,8 @@ remoteFileSize <- function(url) {
 #' @author Alex Chubaty & Eliot McIntire
 #' @export
 #' @importFrom dplyr bind_rows
-#' @importFrom RCurl url.exists
-#' @importFrom reproducible checkPath compareNA
+#' @importFrom reproducible compareNA
+#' @importFrom Require checkPath
 #' @importFrom utils download.file
 #' @rdname downloadData
 #' @examples
