@@ -4,6 +4,15 @@ test_that("test event-level cache", {
     testOnExit(testInitOut)
   }, add = TRUE)
 
+  modPath <- system.file("sampleModules", package = "SpaDES.core")
+
+  mods <- c("caribouMovement", "randomLandscapes", "fireSpread")
+  pkgs <- reqdPkgs(module = mods,
+          modulePath = modPath)
+  expect_true(length(pkgs) == 3)
+  expect_true(all(names(pkgs) == mods))
+  expect_true(all(c("raster", "sp", "SpaDES.tools", "RColorBrewer") %in% unlist(pkgs)))
+
   # Example of changing parameter values
   mySim <- simInit(
     times = list(start = 0.0, end = 1.0, timeunit = "year"),
@@ -14,8 +23,8 @@ test_that("test event-level cache", {
       caribouMovement = list(.plotInitialTime = NA),
       randomLandscapes = list(.plotInitialTime = NA, .useCache = "init", .showSimilar = TRUE)
     ),
-    modules = list("randomLandscapes", "fireSpread", "caribouMovement"),
-    paths = list(modulePath = system.file("sampleModules", package = "SpaDES.core"),
+    modules = mods,
+    paths = list(modulePath = modPath,
                  outputPath = tmpdir,
                  cachePath = tmpdir),
     # Save final state of landscape and caribou
@@ -24,17 +33,20 @@ test_that("test event-level cache", {
   )
 
   set.seed(1123)
-  expect_true(!"Using cached copy of init event in randomLandscapes module" %in%
+  # ._robustDigest_2 <<- ._addChangedAttr_5  <<- ._addTagsToOutput_2 <<- ._Cache_11 <<- ._Cache_13 <<- 1
+  #._addTagsToOutput_2 <<- 1
+  expect_true(!"loaded cached copy of init event in randomLandscapes module" %in%
                 capture_messages({
                   sims <- spades(Copy(mySim), notOlderThan = Sys.time(), debug = FALSE)
                 }))
   #sims <- spades(Copy(mySim), notOlderThan = Sys.time()) ## TODO: fix this test
   landscapeMaps1 <- raster::dropLayer(sims$landscape, "Fires")
   fireMap1 <- sims$landscape$Fires
+  #._doEvent_3 <<- ._prepareOutput_5 <<- 1
   mess1 <- capture_messages({
     sims <- spades(Copy(mySim), debug = FALSE)
   })
-  expect_true(any(grepl(pattern = "Using cached copy of init event in randomLandscapes module", mess1)))
+  expect_true(any(grepl(pattern = "loaded cached copy of init event in randomLandscapes module", mess1)))
   landscapeMaps2 <- raster::dropLayer(sims$landscape, "Fires")
   fireMap2 <- sims$landscape$Fires
 
@@ -76,7 +88,7 @@ test_that("test module-level cache", {
 
   set.seed(1123)
   pdf(tmpfile)
-  expect_true(!("Using cached copy of init event in randomLandscapes module" %in%
+  expect_true(!("loaded cached copy of init event in randomLandscapes module" %in%
                   capture_messages({
                     sims <- spades(Copy(mySim), notOlderThan = Sys.time(), debug = FALSE)
                   })))
@@ -101,7 +113,7 @@ test_that("test module-level cache", {
 
   unlink(tmpfile1)
 
-  expect_true(any(grepl(pattern = "Using cached copy of randomLandscapes module", mess1)))
+  expect_true(any(grepl(pattern = "loaded cached copy of randomLandscapes module", mess1)))
   landscapeMaps2 <- raster::dropLayer(sims$landscape, "Fires")
   fireMap2 <- sims$landscape$Fires
 
@@ -179,7 +191,7 @@ test_that("test .robustDigest for simLists", {
   msgGrep <- "Running .input|module code|Setting|Paths|using dataPath|There is no similar item in the cacheRepo"
   expect_true(all(grepl(msgGrep, mess1)))
 
-  msgGrep <- "Running .input|Using cached copy|module code|Setting|Paths"
+  msgGrep <- "Running .input|loaded cached copy|module code|Setting|Paths"
   #a <- capture.output(
   expect_message(do.call(simInit, args), regexp = msgGrep)
   #)
@@ -215,7 +227,7 @@ test_that("test .robustDigest for simLists", {
   opts <- options(spades.saveSimOnExit = FALSE)
   expect_silent(spades(bbb, debug = FALSE))
   options(opts)
-  expect_message(spades(bbb), regexp = "Using cached copy of init", all = FALSE)
+  expect_message(spades(bbb), regexp = "loaded cached copy of init", all = FALSE)
 
   # make a change in Init function
   xxx <- readLines(fileName)
@@ -226,13 +238,13 @@ test_that("test .robustDigest for simLists", {
   cat(xxx, file = fileName, sep = "\n")
 
   bbb <- do.call(simInit, args)
-  expect_true(any(grepl(format(bbb$test$Init), pattern = newCode)))
+  expect_true(any(grepl(format(bbb@.xData$.mods$test$Init), pattern = newCode)))
 
   # should NOT use Cached copy, so no message
   opts <- options(spades.saveSimOnExit = FALSE)
   expect_silent(spades(bbb, debug = FALSE))
   options(opts)
-  expect_message(spades(bbb), regexp = "Using cached copy of init", all = FALSE)
+  expect_message(spades(bbb), regexp = "loaded cached copy of init", all = FALSE)
 })
 
 test_that("test .checkCacheRepo with function as reproducible.cachePath", {
@@ -284,7 +296,7 @@ test_that("test objSize", {
 
   a <- simInit(objects = list(d = 1:10, b = 2:20))
   os <- objSize(a)
-  expect_true(length(os) == 5) # 4 objects, the environment, the rest
+  expect_true(length(os) == 6) # 4 objects, the environment, the rest
 })
 
 test_that("Cache sim objs via .Cache attr", {
@@ -326,7 +338,7 @@ test_that("Cache sim objs via .Cache attr", {
       sim$co1 <- 1
       sim$co2 <- 1
       sim$co3 <- 1
-      sim$test$hi <- 1
+      sim$.mods$test$hi <- 1
       mod$hello <- 2
       ",
       xxx1[[1]][(lineWithInit + 1):lineWithDotInputObjects], "
@@ -348,7 +360,7 @@ test_that("Cache sim objs via .Cache attr", {
   expect_true(mySim2$co5 == 6)
 
   # Test mod
-  expect_true(mySim2$test$.objects$hello == 2)
+  expect_true(mySim2$.mods$test$.objects$hello == 2)
 
   mySim <- simInit(paths = list(modulePath = tmpdir), modules = as.list(m[1]),
                    objects = list(co4 = 3, co3 = 2, co1 = 4), params =
@@ -356,9 +368,9 @@ test_that("Cache sim objs via .Cache attr", {
 
   expect_true(mySim$co3 == 2) # will be changed by init
   expect_true(mySim$co1 == 4)# will be changed by init
-  expect_true(is.null(mySim$test$hi)) # will be changed by init
+  expect_true(is.null(mySim$.mods$test$hi)) # will be changed by init
   mySim2 <- spades(Copy(mySim))
-  expect_true(mySim2$test$hi == 1) # was affected
+  expect_true(mySim2$.mods$test$hi == 1) # was affected
   expect_true(mySim2$co1 == 1) # was affected
   expect_true(mySim2$co2 == 1)# was affected
   expect_true(mySim2$co3 == 1) # was affected
@@ -367,17 +379,17 @@ test_that("Cache sim objs via .Cache attr", {
   expect_true(is.null(mySim2$co5)) # wan't affected, and isn't there
 
   # Try again, hi should be there
-  expect_true(is.null(mySim$test$hi)) # is not in the
-  mess1 <- capture_messages(
+  expect_true(is.null(mySim$.mods$test$hi)) # is not in the
+  # ._prepareOutput_5 <<- ._addChangedAttr_5  <<- ._addTagsToOutput_2 <<-  1
+  mess1 <- capture_messages({
     mySim2 <- spades(Copy(mySim))
-  )
-  expect_true(mySim2$test$hi == 1) # recovered in Cache
+  })
+  expect_true(mySim2$.mods$test$hi == 1) # recovered in Cache
   # Test mod
-  expect_true(mySim2$test$.objects$hello == 2) # recovered in Cache
-  expect_true(any(grepl("Using cached copy", mess1)))
+  expect_true(mySim2$.mods$test$.objects$hello == 2) # recovered in Cache
+  expect_true(any(grepl("loaded cached copy", mess1)))
 })
 
-
 test_that("test showSimilar", {
   testInitOut <- testInit(smcc = FALSE, "raster")
   on.exit({
@@ -407,14 +419,21 @@ test_that("test showSimilar", {
 
   out1 <- spades(Copy(mySim))#, showSimilar = TRUE)
   params(mySim)$randomLandscapes$nx <- 101
-  mess <- capture_messages(out2 <- spades(Copy(mySim)))#, showSimilar = TRUE)
+  mess <- capture_messages({
+    out2 <- spades(Copy(mySim))#, showSimilar = TRUE)
+  })
   mySim$a <- 1
-  mess <- capture_messages(out1 <- Cache(spades, Copy(mySim), showSimilar = TRUE))
+  mess <- capture_messages({
+    out1 <- Cache(spades, Copy(mySim), showSimilar = TRUE)
+  })
   expect_true(any(grepl("This call to cache differs", mess)))
   mySim$a <- 2
-  mess <- capture_messages(out1 <- Cache(spades, Copy(mySim), showSimilar = TRUE))
+  mess <- capture_messages({
+    out1 <- Cache(spades, Copy(mySim), showSimilar = TRUE)
+  })
   expect_true(any(grepl("This call to cache differs", mess)))
-  mess <- capture_messages(out1 <- Cache(spades, Copy(mySim), showSimilar = TRUE))
+  mess <- capture_messages({
+    out1 <- Cache(spades, Copy(mySim), showSimilar = TRUE)
+  })
   expect_false(any(grepl("This call to cache differs", mess)))
-
 })
